/*******************************************************************************
AnalogDebounced Arduino library http://libahunt.ee/analogdebounced
by Anna Jõgi a.k.a Libahunt
Public domain

For
- using one analog input for multiple (2-5) buttons input
- doing so in a debounced way, because analog transitions are 
especially prone to give faulty results on single reading.
*******************************************************************************/

#include "Arduino.h"
#include "AnalogDebounced.h"


AnalogDebounced::AnalogDebounced(int pinNumber, unsigned long debounceDelay, int numberOfButtons, int *valueMappings) {

  pin = pinNumber;
	buttons = numberOfButtons;
  dbDelay = debounceDelay;
  for (i=0; i<buttons; i++) {
		mappings[i*2] = valueMappings[i]-25;
		mappings[i*2+1] = valueMappings[i]+25;
	}
	lastDbState = readMapped(pin);
	value = lastDbState;
  lastDbTime = millis();
	
}

int AnalogDebounced::readMapped(int pin) {
	int reading = analogRead(pin);
	for (i=0; i<buttons; i++) {
		if (reading > mappings[i*2] && reading < mappings[i*2+1]) {
			return i+1;
		}
	}
	return 0;
}

int AnalogDebounced::dbRead() {
  int dbState = readMapped(pin);
  if (dbState != lastDbState) {// if reading changes
    lastDbTime = millis();     //      we reset timer
  }
  lastDbState = dbState;       //save current reading for next loop
  if ((millis() - lastDbTime) > dbDelay) {  //if reading has been constant for long enough
    value = dbState;                        //    we assign reading as new value
  }
  return value; //return value
}
