/*
AnalogDebounced library http://libahunt.ee/analogdebounced
by Anna Jõgi a.k.a Libahunt
Public domain

For
- using one analog input for multiple (2-5) buttons input
- doing so in a debounced way, because analog transitions are especially prone to give faulty results on single reading.

* Currently maximum number of buttons on one pin is 5. If you need more, you have to tweak things inside the library files.
* The tolerance for variability is set to +-25 analogRead() steps from the value you map. Tweak the library files to change.

You can use more than one analog pins - simply create multiple AnalogDebounced objects.

Example circuit

5V -------------------------------
                   |             |
                   |            10K
                   |             |
                Button1        Button2               I
                   |             |
A0 -------------------------------
                   |
                  10K
                   |
GND ----------------

*/

#include <AnalogDebounced.h> 

int buttonPin = A0;

//Create AnalogDebounced object

//But first you have to specify the approimate values that appear in analogRead when each button is pressed
int analogButtonReadingsMap[2] = {1023, 511};
//There is a tolerance of +-25 analogread steps programmed into the library. So the values in map must be more than 50 steps apart from each other

//AnalogDebounced myAnalogButtonsObjectName = AnalogDebounced(int pinNumber, unsigned long debounceDelay, int numberOfButtonOnPin, analogReadingsMap);
AnalogDebounced buttons = AnalogDebounced(buttonPin, 100, 2, analogButtonReadingsMap);



void setup() {
  
  /*Serial is for example purposes*/
  Serial.begin(9600);
  Serial.println("Button press read:    AnalogRead:");
  
}

void loop() {
  
  //USAGE
  //the dbRead function has to be called from inside loop
  //and so often that reading is repeated at least few times before debounceDelay time passes
  //(analogRead (which the library does) takes 50 microseconds)
  //if you have lots of code executed during each loop or other analog functions, make the debounceDelay, specified in the beginning, longer
  
  //myAnalogButtonsObjectName.dbRead() returns int value of the last state seen stable
  //for the timespan of debounceDelay
  
  // Return value:
  // 0 means that reading does not match any value in analogButtonReadings[]
  // 1 means that the reading matches the first value in analogButtonReadingsMap[] (+-25 tolerance)
  // 2 means that the reading matches the second value in analogButtonReadingsMap[] (+-25 tolerance)
  
  int buttonreading = buttons.dbRead();   
  
  
  /*Serial is for example purposes*/
  Serial.print("           ");
  Serial.print(buttonreading);
  Serial.print("           ");
  Serial.println(analogRead(buttonPin));
  

}

